.. _elgtautclassmodule:

Module ``diffstrata.elgtautclass``
==================================

.. automodule:: admcycles.diffstrata.elgtautclass
   :members:
   :undoc-members:
   :show-inheritance:
